Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(786)

Unified Diff: chrome/test/android/javatests/src/org/chromium/chrome/test/util/ChromeSigninUtils.java

Issue 1288643003: Added Signin Parameters (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Sami's LGTM Nits Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/android/javatests/src/org/chromium/chrome/test/util/ChromeSigninUtils.java
diff --git a/chrome/test/android/javatests/src/org/chromium/chrome/test/util/ChromeSigninUtils.java b/chrome/test/android/javatests/src/org/chromium/chrome/test/util/ChromeSigninUtils.java
index f63b1765630eccf3df8091280e0780187df07ab8..7585cd9e3f29565585f47590bcdd803813e791aa 100644
--- a/chrome/test/android/javatests/src/org/chromium/chrome/test/util/ChromeSigninUtils.java
+++ b/chrome/test/android/javatests/src/org/chromium/chrome/test/util/ChromeSigninUtils.java
@@ -10,9 +10,9 @@ import android.accounts.AccountManagerCallback;
import android.accounts.AccountManagerFuture;
import android.accounts.AuthenticatorException;
import android.accounts.OperationCanceledException;
+import android.app.Instrumentation;
import android.content.Context;
import android.os.Bundle;
-import android.test.InstrumentationTestCase;
import android.text.TextUtils;
import org.chromium.sync.signin.ChromeSigninController;
@@ -41,11 +41,12 @@ public class ChromeSigninUtils {
/**
* The constructor for SigninUtils for a given test case.
*
* @param testCase the test case to perform signin operations with.
*/
- public ChromeSigninUtils(InstrumentationTestCase testCase) {
- mContext = testCase.getInstrumentation().getContext();
- mTargetContext = testCase.getInstrumentation().getTargetContext();
+ public ChromeSigninUtils(Instrumentation instrumentation) {
+ mContext = instrumentation.getContext();
+ mTargetContext = instrumentation.getTargetContext();
mAccountManager = AccountManager.get(mContext);
mMockAccountManager = new MockAccountManager(mContext, mTargetContext);
}
@@ -41,11 +41,12 @@ public class ChromeSigninUtils {
* The constructor for SigninUtils for a given test case.
*
- * @param testCase the test case to perform signin operations with.
+ * @param instrumentation the {@link android.app.Instrumentation} to perform signin operations
+ * with.
*/

Powered by Google App Engine
This is Rietveld 408576698